@@ -30,9 +30,7 @@
 #include <thai/thctype.h>
 #include <datrie/trie.h>
 
-void    brk_on_unload ();
-
-Trie *  brk_get_dict ();
+Trie *  brk_load_default_dict ();
 
 void    brk_brkpos_hints (const thchar_t *str, int len, char *hints);
 
